html, body {
    padding: 0;
    margin: 0;
    height: 100%;
    font-family: "Roboto", "Helvetica", "Arial", sans-serif;
}

#body {
    height: 100%;
}

.auth-list-text {
    text-transform: capitalize;
}

.card-column {
    flex-basis: 33.33%;
    flex-shrink: 0;
    display: 'flex';
    flex-direction: 'column';
    .droppable {
        padding: 5px 4px;
        border: 1px dashed transparent;
        border-radius: 4px;
        height: calc(100% - 50px);
        &.hovering {
            border-color: grey;
        }
    }
}

.issue-view-dialog {
    .title {
        display: flex;
        flex-direction: row;
        align-items: center;
        padding: 10px 10px 5px 20px;
    }
    .content {
        padding: 20px;
    }
    .controls {
        padding: 10px 20px;
        > * {
            margin-right: 10px;
        }
    }
    .details {
        margin: 10px 20px;
        td {
            padding: 3px 0px;
        }
        tr > td:first-child {
            padding-right: 10px;
            > p {
                font-weight: bold;
            }
        }
    }
}

.card {
    height: 100px;
    margin-bottom: 10px;
    padding: 7px;
    display: flex;
    flex-direction: column;
    > .header {
        display: flex;
        flex-direction: row;
        > .title {
            flex-grow: 1;
            width: min-content;
            max-height: 50px;
            overflow: hidden;
            font-size: 0.9em;
            word-break: break-all;
            padding-right: 5px;
            > a {
                cursor: pointer;
            }
        }
    }
    > .footer {
        flex-grow: 1;
        display: flex;
        flex-direction: row;
        align-items: flex-end;
        > .issue-action-icons {
            margin-right: -6px;
            margin-bottom: -6px;
            opacity: 0;
            transition: opacity 0.3s;
            &.ticking {
                opacity: 1;
            }
        }
    }
    &:hover {
        > .footer > .issue-action-icons {
            opacity: 1;
        }
    }
}

.card-column-header {
    text-align: center;
    text-transform: capitalize;
    margin-bottom: 10px !important;
}

.card-container {
    display: flex;
    flex-direction: row;
    margin-top: 10px;
}

.pb-tooltip {
    padding: 5px 8px;
}

.version {
    opacity: 0.6;
    padding-left: 5px;
    font-size: 0.8em;
    cursor: pointer;
}

.changelog-container {
    margin: 10px;
    .logblock-container {
        &:not(:last-child) {
            margin-bottom: 15px;
        }
        > .title {
            padding: 5px;
            font-size: 1.5em;
        }
        > .date {
            padding-left: 5px;
            opacity: 0.8;
            font-size: 0.9em;
        }
        > .logblock {
            padding-left: 5px;
            > .title {
                padding-left: 5px;
            }
            > .item {
                padding-left: 10px;
            }
        }
    }
}
